@@ -32,7 +32,7 @@ from .install_magic import install_magic
 import matplotlib       # for imshow palette
 import matplotlib.cm as cm
 
-__version__ = '0.2.6'
+__version__ = '0.2.8'
 
 SIZING_METHOD = 'policies'        # or 'sizing_mode'
 
@@ -386,6 +386,11 @@ def parse(*args, x=None, y=None, style=None, color=None, label=None, source=None
                     y = [y]
                 else:                                # list of numpy arrays [np.array([1,2,3]), np.array([3,4,5])]      
                     pass
+            elif isinstance(y[0], pd.Series):       
+                if np.ndim(y[0]) == 0:               # list of pandas series [pd.Series([1,2,3]), pd.Series([4,5,6])]
+                    y = [s.values for s in y]
+                if x is None:
+                    x = [s.index for s in y]
             elif isinstance(y[0], str):              # list of pandas column names
                 if _y is not None:
                     raise TypeError('y of type str is only allowed as a keyword argument')
@@ -491,7 +496,7 @@ def parse(*args, x=None, y=None, style=None, color=None, label=None, source=None
             raise TypeError(f'Unsupported x[0] type: {type(x[0])}')
 
     elif isinstance(x, pd.Series):
-        x = [x.values]
+        x = [x.values]*n
 
     elif isinstance(x, str):
         if _x is not None:
@@ -678,7 +683,7 @@ def _plot(*args, x=None, y=None, style=None, color=None, label=None, line_width=
             p.add_tools(HoverTool(tooltips=[('x', '@x{%F}'), ('y', '@y'), ('name', '$name')],
                         formatters={'@x': 'datetime'}))#, '@y': lat_custom}))
         else:
-            p.add_tools(HoverTool(tooltips = [("x", "@x"),("y", "@y")]))
+            p.add_tools(HoverTool(tooltips = [("x", "@x"),("y", "@y"),('name', '$name')]))
 
     n = len(quintuples)
 
@@ -979,7 +984,7 @@ def mpl_cmap(name):
     return palette
     
 
-def imshow(*ims, p=None, palette='Viridis256', autolevels=True, show_axes=False, show_toolbar=True, 
+def imshow(*ims, p=None, palette='Viridis256', cmap=None, autolevels=True, show_axes=False, show_toolbar=True, 
            width=None, height=None, x_range=None, y_range=None,
            grid=True, flipud=False, hover=False, padding=0.1, 
            merge_tools=True, link=True, toolbar_location='right', show_colorbar=False, # multiple image related
@@ -996,7 +1001,7 @@ def imshow(*ims, p=None, palette='Viridis256', autolevels=True, show_axes=False,
                 raise ValueError(f'len(title) = {len(title)} must be the same as the number of images = {len(ims)}')
         else:
             title = [None] * len(ims)
-        ps = [imshow(im, palette=palette, autolevels=autolevels, show_axes=show_axes, 
+        ps = [imshow(im, palette=palette, cmap=cmap, autolevels=autolevels, show_axes=show_axes, 
                      width=width, height=height, grid=grid, flipud=flipud, 
                      hover=hover, padding=padding, title=title[i], title_location=title_location,
                      show_toolbar=False if merge_tools else show_toolbar, 
@@ -1129,6 +1134,8 @@ def imshow(*ims, p=None, palette='Viridis256', autolevels=True, show_axes=False,
 #                im = np.zeros_like(im, dtype=np.uint8)
 #            else:
 #                im = ((im-_min)/(_max-_min)*255).astype(np.uint8)
+    elif np.issubdtype(im.dtype, bool):
+        _min, _max = 0, 1
     if im.ndim in (2, 3):
         if im.ndim == 2:
 #            colormap = cm.get_cmap(palette)
@@ -1194,8 +1201,15 @@ def show_df(df, get_ws=False):
 #    def _ipython_display_(self):
 #        bp.show(self)
 
-def hstack(*args, merge_tools=False, toolbar_location='right', wrap=False, active_drag=None, **kwargs):
+def hstack(*args, merge_tools=False, toolbar_location='right', wrap=False, active_drag=None, link_x=False, link_y=False, **kwargs):
     args = [a.figure if isinstance(a, Plot) else a for a in args]
+    figures = [arg for arg in args if isinstance(arg, bl.LayoutDOM)]
+    if len(figures) > 1 and link_x:
+        for fig in figures[1:]:
+            fig.x_range = figures[0].x_range
+    if len(figures) > 1 and link_y:
+        for fig in figures[1:]:
+            fig.y_range = figures[0].y_range
     all_bokeh = all(isinstance(arg, bl.LayoutDOM) for arg in args)
     if 'width' not in kwargs:
         if CONFIG.get('figure', {}).get('width', None) == 'max':
@@ -1226,8 +1240,15 @@ def hstack(*args, merge_tools=False, toolbar_location='right', wrap=False, activ
         converted = [BokehWidget(arg) if isinstance(arg, bl.LayoutDOM) else arg for arg in args]
         return ipw.HBox(converted)
 
-def vstack(*args, merge_tools=False, toolbar_location='right', wrap=False, active_drag=None, **kwargs):
+def vstack(*args, merge_tools=False, toolbar_location='right', wrap=False, active_drag=None, link_x=False, link_y=False, **kwargs):
     args = [a.figure if isinstance(a, Plot) else a for a in args]
+    figures = [arg for arg in args if isinstance(arg, bl.LayoutDOM)]
+    if len(figures) > 1 and link_x:
+        for fig in figures[1:]:
+            fig.x_range = figures[0].x_range
+    if len(figures) > 1 and link_y:
+        for fig in figures[1:]:
+            fig.y_range = figures[0].y_range
     all_bokeh = all(isinstance(arg, bl.LayoutDOM) for arg in args)
     if 'width' not in kwargs:
         if CONFIG.get('figure', {}).get('width', None) == 'max':
